@@ -21,6 +21,26 @@
 ndim <- function(x)
   length(dim(x))
 
+find_order <- function(x, order, ...) {
+  if (is.logical(order)) {
+    if(order)
+      order <- seriate(x, ...)
+    else
+      order <- seriate(x, method = "identity", ...)
+  }
+
+  if (is.character(order))
+    order <- seriate(x, method = order, ...)
+
+  if (!inherits(order, "ser_permutation"))
+    order <- ser_permutation(order)
+
+  # for debugging
+  #print(order)
+
+  order
+}
+
 #' Permute the Order in Various Objects
 #'
 #' Provides the generic function and methods for permuting the order of various
@@ -41,9 +61,8 @@ ndim <- function(x)
 #'
 #' For \code{dendrogram} and \code{hclust}, subtrees are rotated to represent
 #' the order best possible. If the order is not achieved perfectly then the
-#' user is warned. This behavior can be changed with the extra parameter
-#' \code{incompatible} which can take the values \code{"warn"} (default),
-#' \code{"stop"} or \code{"ignore"}.
+#' user is warned. See also [reorder.hclust()] for
+#' reordering `hclust` objects.
 #'
 #' @family permutation
 #'
@@ -53,12 +72,15 @@ ndim <- function(x)
 #' @param order an object of class [ser_permutation] which contains
 #' suitable permutation vectors for \code{x}. Alternatively, a character string with the
 #' name of a seriation method appropriate for `x` can be specified (see [seriate()]).
-#' This will perform seriation and permute `x`.
+#' This will perform seriation and permute `x`. The value `TRUE` will permute using the
+#' default seriation method.
 #' @param margin specifies the dimensions to be permuted as a vector with dimension indices.
 #' If `NULL`, \code{order} needs to contain a permutation for all dimensions.
 #' If a single margin is specified, then \code{order} can also contain
 #' a single permutation vector.
 #' \code{margin} are ignored.
+#' @param dist the distance matrix used to create the dendrogram. Only needed if
+#'  order is the name of a seriation method.
 #' @param ...  if `order` is the name of a seriation method, then additional arguments are
 #' passed on to [seriate()].
 #' @returns A permuted object of the same class as `x`.
@@ -85,11 +107,12 @@ ndim <- function(x)
 #' permute(m, "PCA")
 #'
 #' ## permute only rows using PCA
-#' permute(m, o, margin = 1)
+#' permute(m, "PCA", margin = 1)
 #'
-#' # Permute data.frames
+#' # Permute data.frames using heatmap seration (= hierarchical
+#' #  clustering + optimal leaf ordering)
 #' df <- as.data.frame(m)
-#' permute(df, o)
+#' permute(df, "Heatmap")
 #'
 #' # Permute objects in a dist object
 #' d <- dist(m)
@@ -105,14 +128,22 @@ ndim <- function(x)
 #'
 #' permute(l, c(2, 3, 1))
 #'
-#' # Permute a dendrogram
+#' # Permute to reorder dendrogram (see also reorder.hclust)
 #' hc <- hclust(d)
 #' plot(hc)
+#'
 #' plot(permute(hc, 5:1))
+#' plot(permute(hc, 5:1, incompartible = "stop"))
+#'
+#' plot(permute(hc, "OLO", dist = d))
+#' plot(permute(hc, "GW", dist = d))
+#' plot(permute(hc, "MDS", dist = d))
+#' plot(permute(hc, "TSP", dist = d))
 #' @export
 permute <- function(x, order, ...)
   UseMethod("permute")
 
+#' @export
 permute.default <- function(x, order, ...)
   .permute_kd(x, order, ...)
 
@@ -155,13 +186,7 @@ permute.list <- function(x, order, ...)
 #' @rdname permute
 #' @export
 permute.dist <- function(x, order, ...) {
-  if (is.character(order))
-    order <- seriate(x, method = order, ...)
-
-  .nodots(...)
-
-  if (!inherits(order, "ser_permutation"))
-    order <- ser_permutation(order)
+  order <- find_order(x, order, ...)
 
   if (.is_identity_permutation(order[[1]]))
     return(x)
@@ -173,17 +198,36 @@ permute.dist <- function(x, order, ...) {
 
 #' @rdname permute
 #' @export
-permute.dendrogram <- function(x, order, ...) {
-  .nodots(...)
+permute.dendrogram <- function(x, order, dist = NULL,  ...) {
+  # order can be
+  #  * TRUE/FALSE
+  #  * a numeric vector
+  #  * a ser_permutation of length 1
+  #  * a ser_permutation vector
+  #  * a seriation method (requires dist)
 
-  if (length(get_order(order)) != stats::nobs(x))
-    stop("Length of order and number of leaves in dendrogram do not agree!")
+  if (is.logical(order)) {
+    if(!order)
+      return(x)
+    else
+      order <- "OLO"
+  }
 
+  if (is.character(order)) {
+    if (is.null(dist))
+      stop("dist need for seriation-based reordering.")
+
+    suppressWarnings(order <- seriate(dist, method = order, hclust = x, ...))
+  }
 
   # modeled after rotate in dendextend. Copied here to reduce the heavy dependency count of dendextend.
   #  x <- dendextend::rotate(x, order = match(get_order(order), get_order(x)))
   rot <- function (x, order, ...)
   {
+
+    if (length(get_order(order)) != stats::nobs(x))
+    stop("Length of order and number of leaves in dendrogram do not agree!")
+
     if (missing(order)) {
       warning("'order' parameter is missing, returning the tree as it was.")
       return(x)
@@ -216,8 +260,8 @@ permute.dendrogram <- function(x, order, ...) {
 
 #' @rdname permute
 #' @export
-permute.hclust <- function(x, order, ...) {
-  nd <- stats::as.hclust(permute(stats::as.dendrogram(x), order, ...))
+permute.hclust <- function(x, order, dist = NULL, ...) {
+  nd <- stats::as.hclust(permute(stats::as.dendrogram(x), order, dist = dist, ...))
   x$merge <- nd$merge
   x$height <- nd$height
   x$order <- nd$order
@@ -227,7 +271,7 @@ permute.hclust <- function(x, order, ...) {
 
 # helper
 .check_dist_perm <- function(x, order) {
-  if (length(order) != 1L)
+  if (inherits(order, "ser_permutation") && length(order) != 1L)
     stop("dimensions do not match")
 
   if (attr(x, "Size") != length(get_order(order, 1)))
@@ -248,8 +292,16 @@ permute.hclust <- function(x, order, ...) {
 .permute_kd <- function(x, order, margin = NULL, ...) {
 
   # DEPRECATED: Compatibility with old permutation for data.frame
-  if (is.data.frame(x) && is.null(margin) && length(order) == 1 && !is.character(order)) {
-    message(
+  if (is.data.frame(x) &&
+      is.null(margin) &&
+      !is.character(order) &&
+      (
+        inherits(order, "ser_permutation") &&
+        length(order) == 1 ||
+        inherits(order, "ser_permutation_vector") || is.integer(order)
+      )) {
+
+    warning(
       "permute for data.frames with a single seriation order is now deprecated. Specify the margin as follows: 'permute(x, order, margin = 1)'"
     )
     margin <- 1
@@ -263,14 +315,7 @@ permute.hclust <- function(x, order, ...) {
       stop("all margins need to specify a valid dimension in x")
   }
 
-
-  if (is.character(order))
-    order <- seriate(x, method = order, margin = margin, ...)
-
-  .nodots(...)
-
-  if (!inherits(order, "ser_permutation"))
-    order <- ser_permutation(order)
+  order <- find_order(x, order, margin = margin, ...)
 
   if (length(order) != ndim(x) && length(order) != length(margin))
     stop(
@@ -298,20 +343,21 @@ permute.hclust <- function(x, order, ...) {
 }
 
 .permute_1d <- function(x, order, ...) {
-  .nodots(...)
+  if (is.logical(order)) {
+    if(order)
+      stop("No default seritation method for vectors avaialble. Specify the order.")
+    else
+      return(x)
+  }
 
-  if (!inherits(order, "ser_permutation"))
-    order <- ser_permutation(order)
+  order <- ser_permutation(order)
 
   if (length(order) != 1)
     stop("dimensions do not match!")
 
-  if (.is_identity_permutation(order[[1]]))
-    return(x)
-
   perm <- get_order(order, 1)
   if (length(x) != length(perm))
-    stop("some permutation vectors do not fit dimension of data!")
+    stop("The permutation vectors do not fit the length of x!")
 
   x[perm]
 }
@@ -319,8 +365,11 @@ permute.hclust <- function(x, order, ...) {
 
 # if we used proxy we would say:
 #.rearrange_dist <- function (x, order) x[[order]]
+# Note: order can be a subset
 
 .rearrange_dist <- function (x, order) {
+
+
   # make C call
   mode(x) <- "double"
   # as.dist seems to make Size numeric and not integer!
