@@ -10,7 +10,7 @@ extern SEXP gradient(SEXP, SEXP, SEXP);
 extern SEXP inertia_criterion(SEXP, SEXP);
 extern SEXP lazy_path_length(SEXP, SEXP);
 extern SEXP least_squares_criterion(SEXP, SEXP);
-//extern SEXP order_greedy(SEXP);
+extern SEXP measure_of_effectiveness(SEXP, SEXP, SEXP);
 extern SEXP order_length(SEXP, SEXP);
 extern SEXP order_optimal(SEXP, SEXP);
 extern SEXP pathdist_floyd(SEXP);
@@ -25,9 +25,6 @@ extern void permNext(void *, void *);
 extern void F77_NAME(arsa)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(bburcg)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(bbwrcg)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void F77_NAME(cbea)(void *, void *, void *, void *, void *, void *, void *);
-extern void F77_NAME(rbea)(void *, void *, void *, void *, void *, void *, void *);
-extern void F77_NAME(energy)(void *, void *, void *, void *);
 
 static const R_CallMethodDef CallEntries[] = {
     {"ar",                      (DL_FUNC) &ar,                      3},
@@ -36,7 +33,7 @@ static const R_CallMethodDef CallEntries[] = {
     {"inertia_criterion",       (DL_FUNC) &inertia_criterion,       2},
     {"lazy_path_length",        (DL_FUNC) &lazy_path_length,        2},
     {"least_squares_criterion", (DL_FUNC) &least_squares_criterion, 2},
-//    {"order_greedy",            (DL_FUNC) &order_greedy,            1},
+    {"measure_of_effectiveness",(DL_FUNC) &measure_of_effectiveness,3},
     {"order_length",            (DL_FUNC) &order_length,            2},
     {"order_optimal",           (DL_FUNC) &order_optimal,           2},
     {"pathdist_floyd",          (DL_FUNC) &pathdist_floyd,          1},
@@ -57,9 +54,6 @@ static const R_FortranMethodDef FortranEntries[] = {
     {"arsa",   (DL_FUNC) &F77_NAME(arsa),   15},
     {"bburcg", (DL_FUNC) &F77_NAME(bburcg), 10},
     {"bbwrcg", (DL_FUNC) &F77_NAME(bbwrcg), 10},
-    {"cbea",   (DL_FUNC) &F77_NAME(cbea),    7},
-    {"rbea",   (DL_FUNC) &F77_NAME(rbea),    7},
-    {"energy", (DL_FUNC) &F77_NAME(energy),  4},
     {NULL, NULL, 0}
 };
 
